@@ -19,7 +19,7 @@ import aiobotocore
 import botocore
 import aiobotocore.session
 from aiobotocore.config import AioConfig
-from botocore.exceptions import ClientError, ParamValidationError
+from botocore.exceptions import ClientError, HTTPClientError, ParamValidationError
 
 from s3fs.errors import translate_boto_error
 from s3fs.utils import S3BucketRegionCache, ParamKwargsHelper, _get_brange, FileExpired
@@ -46,7 +46,7 @@ if "S3FS_LOGGING_LEVEL" in os.environ:
 
 
 MANAGED_COPY_THRESHOLD = 5 * 2**30
-S3_RETRYABLE_ERRORS = (socket.timeout, IncompleteRead)
+S3_RETRYABLE_ERRORS = (socket.timeout, HTTPClientError, IncompleteRead)
 
 if ClientPayloadError is not None:
     S3_RETRYABLE_ERRORS += (ClientPayloadError,)
@@ -1071,7 +1071,7 @@ class S3FileSystem(AsyncFileSystem):
                     **self.req_kw,
                 )
                 return {
-                    "ETag": out["ETag"],
+                    "ETag": out.get("ETag", ""),
                     "LastModified": out["LastModified"],
                     "size": out["ContentLength"],
                     "name": "/".join([bucket, key]),
